@@ -20,7 +20,7 @@
 #   include "config.h"
 #endif
 #include "php.h"
-#if HAVE_ZIP
+#ifdef HAVE_ZIP
 #ifdef ZEND_ENGINE_2
 
 #include "php_streams.h"
@@ -48,7 +48,7 @@ static size_t php_zip_ops_read(php_stream *stream, char *buf, size_t count TSRML
 	ssize_t n = 0;
 	STREAM_DATA_FROM_STREAM();
 
-	if (self->za && self->zf) {
+	if (self->zf) {
 		n = zip_fread(self->zf, buf, count);
 		if (n < 0) {
 #if LIBZIP_VERSION_MAJOR < 1
@@ -208,51 +208,31 @@ php_stream_ops php_stream_zipio_ops = {
 };
 
 /* {{{ php_stream_zip_open */
-php_stream *php_stream_zip_open(const char *filename, const char *path, const char *mode STREAMS_DC TSRMLS_DC)
+php_stream *php_stream_zip_open(struct zip *arch, const char *path, const char *mode STREAMS_DC TSRMLS_DC)
 {
 	struct zip_file *zf = NULL;
-	int err = 0;
-
 	php_stream *stream = NULL;
 	struct php_zip_stream_data_t *self;
-	struct zip *stream_za;
 
 	if (strncmp(mode,"r", strlen("r")) != 0) {
 		return NULL;
 	}
 
-	if (filename) {
-		if (ZIP_OPENBASEDIR_CHECKPATH(filename)) {
-			return NULL;
-		}
-
-		/* duplicate to make the stream za independent (esp. for MSHUTDOWN) */
-		stream_za = zip_open(filename, ZIP_CREATE, &err);
-		if (!stream_za) {
-			return NULL;
-		}
-
-		zf = zip_fopen(stream_za, path, 0);
+	if (arch) {
+		zf = zip_fopen(arch, path, 0);
 		if (zf) {
 			self = emalloc(sizeof(*self));
 
-			self->za = stream_za;
+			self->za = NULL; /* to keep it open on stream close */
 			self->zf = zf;
 			self->stream = NULL;
 			self->cursor = 0;
 			stream = php_stream_alloc(&php_stream_zipio_ops, self, NULL, mode);
 			stream->orig_path = estrdup(path);
-		} else {
-			zip_close(stream_za);
 		}
 	}
 
-	if (!stream) {
-		return NULL;
-	} else {
-		return stream;
-	}
-
+	return stream;
 }
 /* }}} */
 
